summaryrefslogtreecommitdiff
path: root/svtools/source/urlobj
diff options
context:
space:
mode:
Diffstat (limited to 'svtools/source/urlobj')
-rw-r--r--svtools/source/urlobj/inetimg.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/svtools/source/urlobj/inetimg.cxx b/svtools/source/urlobj/inetimg.cxx
index 65a04b1d5a7c..7dd316a57f81 100644
--- a/svtools/source/urlobj/inetimg.cxx
+++ b/svtools/source/urlobj/inetimg.cxx
@@ -95,7 +95,7 @@ sal_Bool INetImage::Read( SvStream& rIStm, sal_uIntPtr nFormat )
/*
--> structure size MUST - alignment of 4!
int iSize; // size of all data, including variable length strings
- BOOL bIsMap; // For server side maps
+ sal_Bool bIsMap; // For server side maps
sal_Int32 iWidth; // Fixed size data correspond to fields in LO_ImageDataStruct
sal_Int32 iHeight; // and EDT_ImageData
sal_Int32 iHSpace;
@@ -112,7 +112,7 @@ sal_Bool INetImage::Read( SvStream& rIStm, sal_uIntPtr nFormat )
ByteString sData;
nFilePos = rIStm.Tell();
// skip over iSize (int), bIsMao ( BOOL ) alignment of 4 !!!!
rIStm.SeekRel( 8 );
rIStm >> nVal; aSizePixel.Width() = nVal;
rIStm >> nVal; aSizePixel.Height() = nVal;
@@ -112,7 +112,7 @@ sal_Bool INetImage::Read( SvStream& rIStm, sal_uIntPtr nFormat )
ByteString sData;
nFilePos = rIStm.Tell();
- // skip over iSize (int), bIsMao ( BOOL ) alignment of 4 !!!!
+ // skip over iSize (int), bIsMao ( sal_Bool ) alignment of 4 !!!!
rIStm.SeekRel( 8 );
rIStm >> nVal; aSizePixel.Width() = nVal;